@@ -32,7 +32,7 @@ __all__: Final[tuple[str, ...]] = (
     "PickleSerializer",
     "Request",
     "Response",
-    "WSGIHandler"
+    "WSGIHandler",
 )
 
-__version__: Final[str] = "2.4.2"
+__version__: Final[str] = "2.4.6"
