@@ -17,7 +17,7 @@ from abc import ABCMeta, abstractmethod
 from collections import UserDict as Dict
 from collections.abc import Callable
 from functools import partial
-from inspect import Signature, isfunction
+from inspect import BoundArguments, isfunction, signature
 from typing import Any, Final, Protocol, TypeAlias, TypeVar, cast, overload
 
 from ._errors import Error, ErrorEnum
@@ -30,11 +30,16 @@ _FuncT = TypeVar("_FuncT", bound=_AnyCallable)
 
 class register_decorator(Protocol):
     @overload
-    def __call__(self, user_function: _FuncT, /) -> _FuncT: ...
+    def __call__(self, user_function: _FuncT, /) -> _FuncT:
+        ...
+
     @overload
-    def __call__(self, user_function: _FuncT, *, function_name: str | None = ...) -> _FuncT: ...
+    def __call__(self, user_function: _FuncT, *, function_name: str | None = ...) -> _FuncT:
+        ...
+
     @overload
-    def __call__(self, *, function_name: str | None = ...) -> Callable[[_FuncT], _FuncT]: ...
+    def __call__(self, *, function_name: str | None = ...) -> Callable[[_FuncT], _FuncT]:
+        ...
 
 
 class BaseDispatcher(Dict[str, _AnyCallable], metaclass=ABCMeta):
@@ -44,7 +49,7 @@ class BaseDispatcher(Dict[str, _AnyCallable], metaclass=ABCMeta):
         return hash(frozenset(self.items()))
 
     def __repr__(self) -> str:
-        return f"<{self.__class__.__qualname__}({self.data!r})>"
+        return f"{self.__class__.__name__}({self.data!r})"
 
     @property
     @abstractmethod
@@ -67,6 +72,7 @@ class Dispatcher(BaseDispatcher):
         >>> dispatcher["func"]
         <function <lambda> at 0x\u2026>
     """
+
     __slots__: tuple[str, ...] = ()
 
     @property
@@ -92,6 +98,7 @@ class Dispatcher(BaseDispatcher):
             or function with the provided name is already defined in the :class:`jsonrpc.Dispatcher` class.
         :returns: The unmodified ``user_function`` object, passed in the parameters.
         """
+
         def wrapper(user_function: _FuncT | None = None, *, function_name: str | None = None) -> _FuncT | Callable[[_FuncT], _FuncT]:
             if user_function is None:
                 return cast(Callable[[_FuncT], _FuncT], partial(wrapper, function_name=function_name))
@@ -130,12 +137,12 @@ class Dispatcher(BaseDispatcher):
             raise Error(code=ErrorEnum.METHOD_NOT_FOUND, message=f"Function {function_name!r} isn't found") from exc
 
         try:
-            Signature.from_callable(user_function).bind(*args, **kwargs)
+            params: Final[BoundArguments] = signature(user_function).bind(*args, **kwargs)
         except TypeError as exc:
             raise Error(code=ErrorEnum.INVALID_PARAMETERS, message=f"Invalid parameters: {exc!s}") from exc
 
         try:
-            return user_function(*args, **kwargs)
+            return user_function(*params.args, **params.kwargs)
         except Error:
             raise
         except Exception as exc:
