@@ -17,19 +17,20 @@ from abc import ABCMeta, abstractmethod
 from collections import UserList as List
 from collections.abc import Iterable, MutableMapping, MutableSequence
 from numbers import Number
+from re import match as _regex_match
 from typing import Any, Final, Literal, TypeAlias, TypeVar, Union
 
 from ._errors import BaseError, Error, ErrorEnum
 from ._utilities import Undefined, UndefinedType, make_hashable
 
-__all__: Final[tuple[str, ...]] = ("BatchRequest", "Request")
+__all__: Final[tuple[str, ...]] = (
+    "BatchRequest",
+    "Request",
+)
 
 _Params: TypeAlias = list[object] | dict[str, object]
 _BaseRequestOrError = TypeVar("_BaseRequestOrError", bound=Union["BaseRequest", BaseError])
 
-# Method names that begins with the "rpc." prefix are reserved for internal usage only:
-_INVALID_SIGNATURE: Final[str] = "\x72\x70\x63\x2E"
-
 
 class BaseRequest(metaclass=ABCMeta):
     __slots__: tuple[str, ...] = ()
@@ -72,7 +73,7 @@ class BaseBatchRequest(List[_BaseRequestOrError], metaclass=ABCMeta):
         return hash(tuple(self.data))
 
     def __repr__(self) -> str:
-        return f"<{self.__class__.__qualname__}({self.data!r})>"
+        return f"{self.__class__.__name__}({self.data!r})"
 
     @staticmethod
     @abstractmethod
@@ -94,6 +95,7 @@ class Request(BaseRequest):
         aren't an objects of type :py:class:`collections.abc.MutableSequence` or :py:class:`collections.abc.MutableMapping` if provided,
         also if the request identifier isn't an object of type :py:class:`str` or :py:class:`numbers.Number` if provided.
     """
+
     __slots__: tuple[str, ...] = ("_method", "_params", "_id")
 
     def __init__(
@@ -101,17 +103,14 @@ class Request(BaseRequest):
         *,
         method: str,
         params: _Params | UndefinedType = Undefined,
-        request_id: str | float | UndefinedType = Undefined
+        request_id: str | float | UndefinedType = Undefined,
     ) -> None:
         self._method: Final[str] = self._validate_method(method) and method
         self._params: Final[_Params | UndefinedType] = self._validate_params(params) and params
         self._id: Final[str | float | UndefinedType] = self._validate_id(request_id) and request_id
 
     def __repr__(self) -> str:
-        return f"<{self.__class__.__qualname__}(" \
-            f"method={self._method!r}, " \
-            f"params={self._params!r}, " \
-            f"request_id={self._id!r})>"
+        return f"{self.__class__.__name__}(method={self._method!r}, params={self._params!r}, request_id={self._id!r})"
 
     def __hash__(self) -> int:
         return hash((self._method, make_hashable(self._params), self._id))
@@ -119,27 +118,30 @@ class Request(BaseRequest):
     def __eq__(self, obj: Any) -> bool:
         if not isinstance(obj, self.__class__):
             return NotImplemented
-        return (self._method, self._params, self._id) == (obj.method, obj._params, obj._id)
+        return (self._method, self._params, self._id) == (obj._method, obj._params, obj._id)
 
     def _validate_method(self, method: Any) -> Literal[True]:
-        if not isinstance(method, str) or method.startswith(_INVALID_SIGNATURE, 0, len(_INVALID_SIGNATURE)):
+        if not isinstance(method, str) or _regex_match("\x5E\x72\x70\x63\x5C\x2E", method):
             raise Error(
                 code=ErrorEnum.INVALID_REQUEST,
-                message=f"Request method must be a string and doesn't have a {_INVALID_SIGNATURE!r} prefix")
+                message="Request method must be a string and should not have a 'rpc.' prefix",
+            )
         return True
 
     def _validate_params(self, params: Any) -> Literal[True]:
         if not isinstance(params, MutableSequence | MutableMapping | UndefinedType):
             raise Error(
                 code=ErrorEnum.INVALID_REQUEST,
-                message=f"Request params must be a sequence or mapping, not a {type(params).__name__!r}")
+                message=f"Request params must be a sequence or mapping, not a {type(params).__name__!r}",
+            )
         return True
 
     def _validate_id(self, request_id: Any) -> Literal[True]:
         if not isinstance(request_id, str | Number | UndefinedType):
             raise Error(
                 code=ErrorEnum.INVALID_REQUEST,
-                message=f"Request id must be an optional string or number, not a {type(request_id).__name__!r}")
+                message=f"Request id must be an optional string or number, not a {type(request_id).__name__!r}",
+            )
         return True
 
     @property
@@ -188,9 +190,9 @@ class Request(BaseRequest):
         Example usage::
 
             >>> Request.from_json({"jsonrpc": "2.0", "method": "foobar", "id": 1})
-            <Request(method="foobar", params=Undefined, request_id=1)>
+            Request(method="foobar", params=Undefined, request_id=1)
             >>> Request.from_json({"not_jsonrpc": True})
-            <Error(code=-32600, message="Invalid request object", data={"not_jsonrpc": True})>
+            Error(code=-32600, message="Invalid request object", data={"not_jsonrpc": True})
         """
         try:
             match obj:
@@ -213,6 +215,7 @@ class BatchRequest(BaseBatchRequest[Request | Error]):
     The :py:class:`collections.UserList` subclass representing the collection
     of :class:`jsonrpc.Request` and :class:`jsonrpc.Error` objects.
     """
+
     __slots__: tuple[str, ...] = ()
 
     @staticmethod
@@ -228,6 +231,6 @@ class BatchRequest(BaseBatchRequest[Request | Error]):
             ...     {"jsonrpc": "2.0", "method": "foobar", "id": 1},
             ...     {"not_jsonrpc": True}
             ... ])
-            <BatchRequest((<Request(\u2026)>, <Error(\u2026)>))>
+            BatchRequest([Request(\u2026), Error(\u2026)])
         """
         return BatchRequest(map(Request.from_json, iterable))
