@@ -13,21 +13,25 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import json as _json
+import pickle as _pickle
 from abc import ABCMeta, abstractmethod
-from json import dumps as _json_encode, loads as _json_decode
-from pickle import HIGHEST_PROTOCOL, dumps as _pickle_encode, loads as _pickle_decode
+from io import BytesIO, StringIO
 from typing import Any, ClassVar, Final
 
 from ._errors import Error, ErrorEnum
 
-__all__: Final[tuple[str, ...]] = ("JSONSerializer", "PickleSerializer")
+__all__: Final[tuple[str, ...]] = (
+    "JSONSerializer",
+    "PickleSerializer",
+)
 
 
 class BaseSerializer(metaclass=ABCMeta):
     __slots__: tuple[str, ...] = ()
 
     def __repr__(self) -> str:
-        return f"<{self.__class__.__qualname__}()>"
+        return f"{self.__class__.__name__}()"
 
     @abstractmethod
     def serialize(self, obj: Any) -> bytes:
@@ -42,6 +46,7 @@ class JSONSerializer(BaseSerializer):
     """
     Simple class for JSON serialization and deserialization.
     """
+
     __slots__: tuple[str, ...] = ()
 
     def serialize(self, obj: Any) -> bytes:
@@ -52,10 +57,12 @@ class JSONSerializer(BaseSerializer):
         :raises jsonrpc.Error: If any exception has occurred due the serialization or/and encoding to :py:class:`bytes`.
         :returns: The :py:class:`bytes` object containing the serialized Python data structure.
         """
-        try:
-            return _json_encode(obj, separators=(",", ":")).encode("latin-1")
-        except Exception as exc:
-            raise Error(code=ErrorEnum.PARSE_ERROR, message="Failed to serialize object to JSON") from exc
+        with StringIO() as raw_buffer:
+            try:
+                _json.dump(obj, raw_buffer, separators=(",", ":"))
+                return raw_buffer.getvalue().encode("latin-1")
+            except Exception as exc:
+                raise Error(code=ErrorEnum.PARSE_ERROR, message="Failed to serialize object to JSON") from exc
 
     def deserialize(self, obj: bytes) -> Any:
         """
@@ -65,21 +72,23 @@ class JSONSerializer(BaseSerializer):
         :raises jsonrpc.Error: If any exception has occurred due the deserialization or/and decoding from :py:class:`bytes`.
         :returns: An any type of object containing the deserialized Python data structure.
         """
-        try:
-            return _json_decode(obj)
-        except Exception as exc:
-            raise Error(code=ErrorEnum.PARSE_ERROR, message="Failed to deserialize object from JSON") from exc
+        with BytesIO(obj) as raw_buffer:
+            try:
+                return _json.load(raw_buffer)
+            except Exception as exc:
+                raise Error(code=ErrorEnum.PARSE_ERROR, message="Failed to deserialize object from JSON") from exc
 
 
 class PickleSerializer(BaseSerializer):
     """
     Simple class for the "Pickling" and "Unpickling" Python objects.
     """
+
     __slots__: tuple[str, ...] = ()
 
     #: Pickle protocol version used for the serialization.
     #: Defaults to :py:data:`pickle.HIGHEST_PROTOCOL`.
-    PROTOCOL_VERSION: ClassVar[int] = HIGHEST_PROTOCOL
+    PROTOCOL_VERSION: ClassVar[int] = _pickle.HIGHEST_PROTOCOL
 
     def serialize(self, obj: Any) -> bytes:
         """
@@ -89,10 +98,12 @@ class PickleSerializer(BaseSerializer):
         :raises jsonrpc.Error: If exception has occurred due the pickling.
         :returns: The :py:class:`bytes` object containing the pickled object.
         """
-        try:
-            return _pickle_encode(obj, self.PROTOCOL_VERSION)
-        except Exception as exc:
-            raise Error(code=ErrorEnum.PARSE_ERROR, message="Failed to serialize object") from exc
+        with BytesIO() as raw_buffer:
+            try:
+                _pickle.dump(obj, raw_buffer, self.PROTOCOL_VERSION)
+                return raw_buffer.getvalue()
+            except Exception as exc:
+                raise Error(code=ErrorEnum.PARSE_ERROR, message="Failed to serialize object") from exc
 
     def deserialize(self, obj: bytes) -> Any:
         """
@@ -102,7 +113,8 @@ class PickleSerializer(BaseSerializer):
         :raises jsonrpc.Error: If exception has occurred due the unpickling.
         :returns: An any type of object containing the deserialized Python data structure.
         """
-        try:
-            return _pickle_decode(obj)
-        except Exception as exc:
-            raise Error(code=ErrorEnum.PARSE_ERROR, message="Failed to deserialize object") from exc
+        with BytesIO(obj) as raw_buffer:
+            try:
+                return _pickle.load(raw_buffer)
+            except Exception as exc:
+                raise Error(code=ErrorEnum.PARSE_ERROR, message="Failed to deserialize object") from exc
