@@ -15,20 +15,20 @@
 
 from abc import ABCMeta, abstractmethod
 from collections import UserDict as Dict
-from collections.abc import Iterator, MutableSequence
+from collections.abc import Iterable, Iterator, MutableSequence
 from concurrent.futures import Executor, Future, ThreadPoolExecutor
 from functools import partial
 from http import HTTPStatus
-from io import DEFAULT_BUFFER_SIZE
+from io import DEFAULT_BUFFER_SIZE, BytesIO
 from sys import exc_info
 from traceback import print_exception
 from typing import Any, ClassVar, Final, TypeAlias
 
-from ._dispatcher import Dispatcher
+from ._dispatcher import BaseDispatcher, Dispatcher
 from ._errors import BaseError, Error
 from ._request import BaseBatchRequest, BaseRequest, BatchRequest, Request
 from ._response import BaseBatchResponse, BaseResponse, BatchResponse, Response
-from ._serializer import JSONSerializer
+from ._serializer import BaseSerializer, JSONSerializer
 from ._typing import Headers, InputStream, OptExcInfo, StartResponse, WSGIEnvironment
 
 __all__: Final[tuple[str, ...]] = ("WSGIHandler",)
@@ -44,10 +44,10 @@ class BaseWSGIHandler(Dict[str, Any], metaclass=ABCMeta):
     default_content_type: ClassVar[str] = "application/json"
 
     #: The list of HTTP request methods which are allowed to use.
-    allowed_http_methods: ClassVar[tuple[str, ...]] = ("POST", "PUT")
+    allowed_http_methods: ClassVar[Iterable[str]] = ("POST", "PUT")
 
     def __repr__(self) -> str:
-        return f"<{self.__class__.__qualname__}({self.data!r})>"
+        return f"{self.__class__.__name__}({self.data!r})"
 
     def __call__(self, environ: WSGIEnvironment, start_response: StartResponse) -> Iterator[bytes]:
         # Prevents the "start_response" argument duplicate invocation:
@@ -58,7 +58,7 @@ class BaseWSGIHandler(Dict[str, Any], metaclass=ABCMeta):
             return wsgi_response(status=HTTPStatus.METHOD_NOT_ALLOWED)
 
         try:
-            if not (request_body := b"".join(self._read_request_body(environ))):
+            if not (request_body := self._read_request_body(environ)):
                 # Trying to check the request body is empty.
                 # If that's true then it returns HTTP 400 "Bad Request".
                 return wsgi_response(status=HTTPStatus.BAD_REQUEST)
@@ -77,24 +77,26 @@ class BaseWSGIHandler(Dict[str, Any], metaclass=ABCMeta):
             print_exception(exc, file=environ["wsgi.errors"])
             return wsgi_response(status=HTTPStatus.INTERNAL_SERVER_ERROR, exc_info=exc_info())
 
-    def _read_request_body(self, environ: WSGIEnvironment) -> Iterator[bytes]:
+    def _read_request_body(self, environ: WSGIEnvironment) -> bytes:
         try:
             content_length: int = int(environ["CONTENT_LENGTH"])
         except (KeyError, ValueError):
-            return
+            return b""
 
         stream: Final[InputStream] = environ["wsgi.input"]
 
-        # Ensure to disallow reading the stream more bytes
-        # than specified by "Content-Length" header:
-        while content_length > 0:
-            if not (chunk := stream.read(min(content_length, DEFAULT_BUFFER_SIZE))):
-                raise EOFError(f"Client disconnected, {content_length:d} more bytes were expected")
+        with BytesIO() as raw_buffer:
+            # Ensure to disallow reading the stream more bytes
+            # than specified by "Content-Length" header:
+            while content_length > 0:
+                if not (chunk := stream.read(min(content_length, DEFAULT_BUFFER_SIZE))):
+                    raise EOFError(f"Client disconnected, {content_length:d} more bytes were expected")
 
-            # Yields the chunk of request body to the iterator
-            # and decreases the request size:
-            yield chunk
-            content_length -= len(chunk)
+                # Appends the chunk of request body to the buffer
+                # and decreases the request size:
+                content_length -= raw_buffer.write(chunk)
+
+            return raw_buffer.getvalue()
 
     def _get_response(
         self,
@@ -102,12 +104,12 @@ class BaseWSGIHandler(Dict[str, Any], metaclass=ABCMeta):
         *,
         status: HTTPStatus = HTTPStatus.OK,
         response_body: bytes | None = None,
-        exc_info: OptExcInfo | None = None
+        exc_info: OptExcInfo | None = None,
     ) -> Iterator[bytes]:
         content_length: Final[int] = len(response_body := b"" if response_body is None else response_body)
         headers: Final[Headers] = [
             ("Content-Length", f"{content_length:d}"),
-            ("Content-Type", self.default_content_type)
+            ("Content-Type", self.default_content_type),
         ]
 
         if status == HTTPStatus.METHOD_NOT_ALLOWED:
@@ -116,6 +118,7 @@ class BaseWSGIHandler(Dict[str, Any], metaclass=ABCMeta):
 
         start_response(f"{status.value:d}\u0020{status.phrase!s}", headers, exc_info)
         yield response_body
+        yield b""  # EOF marker
 
     @abstractmethod
     def handle_request(self, deserialized_object: _AnyRequest) -> _AnyResponse:
@@ -139,19 +142,19 @@ class WSGIHandler(BaseWSGIHandler):
         >>> app["my_private_key"]
         "foobar"
     """
+
     __slots__: tuple[str, ...] = ()
 
     #: Class variable representing the :class:`jsonrpc.Dispatcher` object
     #: used by this class for routing user-defined functions by default.
-    dispatcher: ClassVar[Dispatcher] = Dispatcher()
+    dispatcher: ClassVar[BaseDispatcher] = Dispatcher()
 
     #: Class variable representing the :class:`jsonrpc.JSONSerializer` object
     #: used by this class for data serialization by default.
-    serializer: ClassVar[JSONSerializer] = JSONSerializer()
+    serializer: ClassVar[BaseSerializer] = JSONSerializer()
 
-    @classmethod
-    def _handle_deserialized_request(cls, executor: Executor, request: Request) -> Response | None:
-        future: Final[Future[Any]] = executor.submit(cls.dispatcher.dispatch, request.method, *request.args, **request.kwargs)
+    def _handle_deserialized_request(self, executor: Executor, request: Request) -> Response | None:
+        future: Final[Future[Any]] = executor.submit(self.dispatcher.dispatch, request.method, *request.args, **request.kwargs)
         if request.is_notification:
             return None
         try:
@@ -160,17 +163,15 @@ class WSGIHandler(BaseWSGIHandler):
         except Error as error:
             return Response(error=error, response_id=request.request_id)
 
-    @staticmethod
-    def _handle_deserialized_error(error: Error) -> Response:
+    def _handle_deserialized_error(self, error: Error) -> Response:
         return Response(error=error, response_id=None)
 
-    @classmethod
-    def _handle_deserialized_batch_request(cls, executor: Executor, batch_request: BatchRequest) -> BatchResponse:
+    def _handle_deserialized_batch_request(self, executor: Executor, batch_request: BatchRequest) -> BatchResponse:
         def wrapper(obj: Request | Error) -> Response | None:
             if isinstance(obj, Request):
-                return cls._handle_deserialized_request(executor, obj)
+                return self._handle_deserialized_request(executor, obj)
             else:
-                return cls._handle_deserialized_error(obj)
+                return self._handle_deserialized_error(obj)
 
         return BatchResponse(filter(None, executor.map(wrapper, batch_request)))
 
@@ -178,9 +179,8 @@ class WSGIHandler(BaseWSGIHandler):
         """
         Base method for handling deserialized requests.
 
-        :param deserialized_object: One of the following objects types: :class:`jsonrpc.Request`, :class:`jsonrpc.BatchRequest`
-            or :class:`jsonrpc.Error`. If the :class:`jsonrpc.BatchRequest` object type was supplied,
-            its will be invoked itself recursively for each one item containing in the batch request.
+        :param deserialized_object: One of the following objects types:
+            :class:`jsonrpc.Request`, :class:`jsonrpc.BatchRequest` or :class:`jsonrpc.Error`.
         :raises ValueError: Due the invocation with unsupported request type.
         :returns: Either :class:`jsonrpc.Response` or :class:`jsonrpc.BatchResponse`.
             If the :class:`jsonrpc.Request` object was received and it's a notification, then it returns :py:data:`None`.
